==> pystand_pack-1.0.10.tar.gz: pystand_pack-1.0.10/pystand_pack/__init__.py <==
#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: qicongsheng
import os
import re
import shutil
import urllib.request
import zipfile
from importlib.metadata import distribution
from pathlib import Path

from pystand_pack import deptree
from pystand_pack import script


def package(**kwargs):
    output_dir = kwargs['output_dir']
    pystand_download_url = kwargs['pystand_download_url']
    dir_name = kwargs['dir_name']
    exe_name = kwargs['exe_name']
    entry_point = kwargs['entry_point']
    pack_requires = kwargs['pack_requires']
    scripts = kwargs['scripts']
    download_and_unzip(pystand_download_url, output_dir)
    sub_folders = os.listdir(output_dir)
    old_folder = os.path.join(output_dir, sub_folders[0])
    new_folder = os.path.join(output_dir, dir_name)
    os.rename(old_folder, new_folder)
    os.rename(os.path.join(new_folder, 'PyStand.exe'), os.path.join(new_folder, exe_name))
    os.remove(os.path.join(new_folder, 'PyStand.int'))
    os.remove(os.path.join(new_folder, 'README.md'))
    entry_point_file = entry_point.split(':')[0]
    entry_point_func = entry_point.split(':')[1]
    py_strs = [
        "import sys\n",
        "sys.path.append('./script')\n",
        f"import {entry_point_file}\n",
        f"{entry_point_file}.{entry_point_func}()\n",
    ]
    # 打开文件并写入内容
    with open(os.path.join(new_folder, '_pystand_static.int'), "w", encoding="utf-8") as file:
        file.writelines(py_strs)
    copy_packages_to_destination(pack_requires, os.path.join(new_folder, 'site-packages'))
    script.copy_matching_files('./', os.path.join(new_folder, 'script'), scripts)


def copy_script():
    pass


def get_site_packages_path():
    """获取当前 Python 环境的 site-packages 路径"""
    # 通过查找一个已知包的路径来确定 site-packages 目录
    example_package = distribution('pip')  # 使用 pip 作为示例
    return str(Path(example_package.locate_file('')))


def copy_packages_to_destination(pack_requires, destination_dir):
    """根据 requirements.txt 复制包及其依赖到目标目录"""
    site_packages_path = get_site_packages_path()
    pack_requires = set(pack_requires)
    destination_path = Path(destination_dir)
    destination_path.mkdir(parents=True, exist_ok=True)  # 创建目标目录
    all_dependencies = deptree.get_package_dependencies(pack_requires)
    # 复制包及其依赖
    for package in all_dependencies:
        package = re.sub(r"[<>=!].+", "", package)
        package_path = Path(site_packages_path) / package
        if package_path.exists():
            dest_path = destination_path / package
            if dest_path.exists():
                shutil.rmtree(dest_path)  # 如果目标目录已存在，先删除
            shutil.copytree(package_path, dest_path)
            print(f"Copied: {package}")
        else:
            print(f"Skipped: {package} (not found in site-packages)")


def download_and_unzip(url, extract_to):
    try:
        if os.path.exists(extract_to):
            shutil.rmtree(extract_to)  # 递归删除文件夹
        os.makedirs(extract_to)
        zip_path = os.path.join(extract_to, 'temp.zip')
        urllib.request.urlretrieve(url, zip_path)
        with zipfile.ZipFile(zip_path, 'r') as zip_ref:
            zip_ref.extractall(extract_to)
        os.remove(zip_path)
    except Exception as e:
        print(f"发生错误: {e}")

==> pystand_pack-1.0.11.tar.gz: pystand_pack-1.0.11/pystand_pack/__init__.py <==
#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: qicongsheng
import os
import re
import shutil
import urllib.request
import zipfile
from importlib.metadata import distribution
from pathlib import Path

from pystand_pack import deptree
from pystand_pack import script


def package(**kwargs):
    output_dir = kwargs.get('output_dir', 'out')
    pystand_download_url = kwargs.get('pystand_download_url',
                                      'https://r2.nevy.eu.org/dist/pystand/PyStand-py38-pyqt5-win32-lite.zip')
    dist_dir = kwargs.get('dist_dir', 'dist')
    exe_name = kwargs.get('exe_name', 'main.exe')
    entry_point = kwargs.get('entry_point', 'main:start')
    pip_requires = kwargs.get('pip_requires', [])
    module_includes = kwargs.get('module_includes', [])
    module_excludes = kwargs.get('module_excludes', [])
    download_and_unzip(pystand_download_url, output_dir)
    sub_folders = os.listdir(output_dir)
    old_folder = os.path.join(output_dir, sub_folders[0])
    new_folder = os.path.join(output_dir, dist_dir)
    os.rename(old_folder, new_folder)
    os.rename(os.path.join(new_folder, 'PyStand.exe'), os.path.join(new_folder, exe_name))
    os.remove(os.path.join(new_folder, 'PyStand.int'))
    os.remove(os.path.join(new_folder, 'README.md'))
    entry_point_file = entry_point.split(':')[0]
    entry_point_func = entry_point.split(':')[1]
    py_strs = [
        "import sys\n",
        "sys.path.append('./script')\n",
        f"import {entry_point_file}\n",
        f"{entry_point_file}.{entry_point_func}()\n",
    ]
    # 打开文件并写入内容
    with open(os.path.join(new_folder, '_pystand_static.int'), "w", encoding="utf-8") as file:
        file.writelines(py_strs)
    copy_packages_to_destination(pip_requires, os.path.join(new_folder, 'site-packages'))
    script.copy_matching_files('./', os.path.join(new_folder, 'script'), module_includes)
    script.delete_matching_files(os.path.join(new_folder, 'script'), module_excludes)


def get_site_packages_path():
    """获取当前 Python 环境的 site-packages 路径"""
    # 通过查找一个已知包的路径来确定 site-packages 目录
    example_package = distribution('pip')  # 使用 pip 作为示例
    return str(Path(example_package.locate_file('')))


def copy_packages_to_destination(pip_requires, destination_dir):
    """根据 requirements.txt 复制包及其依赖到目标目录"""
    site_packages_path = get_site_packages_path()
    pip_requires = set(pip_requires)
    destination_path = Path(destination_dir)
    destination_path.mkdir(parents=True, exist_ok=True)  # 创建目标目录
    all_dependencies = deptree.get_package_dependencies(pip_requires)
    # 复制包及其依赖
    for package in all_dependencies:
        package = re.sub(r"[<>=!].+", "", package)
        package_path = Path(site_packages_path) / package
        if package_path.exists():
            dest_path = destination_path / package
            if dest_path.exists():
                shutil.rmtree(dest_path)  # 如果目标目录已存在，先删除
            shutil.copytree(package_path, dest_path)
            print(f"Copied: {package}")
        else:
            print(f"Skipped: {package} (not found in site-packages)")


def download_and_unzip(url, extract_to):
    try:
        if os.path.exists(extract_to):
            shutil.rmtree(extract_to)  # 递归删除文件夹
        os.makedirs(extract_to)
        zip_path = os.path.join(extract_to, 'temp.zip')
        urllib.request.urlretrieve(url, zip_path)
        with zipfile.ZipFile(zip_path, 'r') as zip_ref:
            zip_ref.extractall(extract_to)
        os.remove(zip_path)
    except Exception as e:
        print(f"发生错误: {e}")
